@@ -26,9 +26,10 @@ from jupyter_client.localinterfaces import localhost
 
 
 class Heartbeat(Thread):
-    "A simple ping-pong style heartbeat that runs in a thread."
+    """A simple ping-pong style heartbeat that runs in a thread."""
 
     def __init__(self, context, addr=None):
+        """Initialize the heartbeat thread."""
         if addr is None:
             addr = ("tcp", localhost(), 0)
         Thread.__init__(self, name="Heartbeat")
@@ -44,6 +45,7 @@ class Heartbeat(Thread):
         self.name = "Heartbeat"
 
     def pick_port(self):
+        """Pick a port for the heartbeat."""
         if self.transport == "tcp":
             s = socket.socket()
             # '*' means all interfaces to 0MQ, which is '' to socket.socket
@@ -52,7 +54,7 @@ class Heartbeat(Thread):
             s.close()
         elif self.transport == "ipc":
             self.port = 1
-            while os.path.exists("%s-%s" % (self.ip, self.port)):
+            while os.path.exists(f"{self.ip}-{self.port}"):
                 self.port = self.port + 1
         else:
             raise ValueError("Unrecognized zmq transport: %s" % self.transport)
@@ -60,11 +62,11 @@ class Heartbeat(Thread):
 
     def _try_bind_socket(self):
         c = ":" if self.transport == "tcp" else "-"
-        return self.socket.bind("%s://%s" % (self.transport, self.ip) + c + str(self.port))
+        return self.socket.bind(f"{self.transport}://{self.ip}" + c + str(self.port))
 
     def _bind_socket(self):
         try:
-            win_in_use = errno.WSAEADDRINUSE
+            win_in_use = errno.WSAEADDRINUSE  # type:ignore[attr-defined]
         except AttributeError:
             win_in_use = None
 
@@ -89,6 +91,7 @@ class Heartbeat(Thread):
                 return
 
     def run(self):
+        """Run the heartbeat thread."""
         self.name = "Heartbeat"
         self.socket = self.context.socket(zmq.ROUTER)
         self.socket.linger = 1000
